% Tell me about Tonto2.

**Tonto2** is a list keeper.     
                                 
It is a **Python3** script that uses **Qt** for its graphical
interface. It runs on **Windows** desktops as well as **Linux**
desktops. It does not interact with cloud-based services. If you want
to import or export data to the cloud, you need to do that outside of
Tonto2.
                                 
# What does Tonto2 do?
                                 
It keeps lists.                  
                                 
You can use lists to keep in touch with family, friends, and
cow-orkers.
                                 
Tonto2 is quick to learn, easy to understand, and simple to use.
                                 
Tonto2 keeps four kinds of lists:
                                 
- You can use an address list to keep track of contacts\' phone
  numbers, mailing addresses, and eMail addresses.
                                 
- You can use a calendar to remind you about events and appointments
  including date, time, and duration. You can add notes about finding
  the location and other prerequisites to attendance.
                                 
- You can keep separate passwords in a password list for every website
  you visit and every piece of gear you own.
                                 
- You can keep links to favorite websites in a bookmark list.
                                 
Additionally you can make a list of bibliographic entries for writing
research papers and for saving well-formatted footnotes for Web sites,
but this is an arcane topic that will probably not be of general
interest.
                                 
The information in these lists is at your fingertips.
                                 
You own it, and you can keep it.  You can share it piecemeal with
other people and computers without having to trust anyone or any thing
with the whole enchilada. This is the idea of Tonto2.
                                 
# Is that all it does?
                                 
Well \... yes.                   
                                 
It doesn\'t spill its guts to Big Media, Big Government, or Big Crime,
if that\'s what you\'re asking.
                                 
It won\'t necessarily keep you safe from threats, but then it won\'t
try to monetize your information, either.
                                 
It\'s free: There are no registration fees, no membership fees, no
storage fees, no usage fees, no access fees, and no service fees.
                                 
The information you put into lists is stored in comma-separated-values
(**csv**) files on your computer, not in the cloud. You can import these
files to spreadsheets if you want. If you run programs that generate
**csv** files, you can read those files in Tonto2.
                                 
# Who am I to use Tonto2?
                                 
I wrote Tonto2 for geeks because I am one. If you are a geek, you\'ll
love it. If you\'re not, you need to **pretend to be one** to
appreciate the technical details that follow.
                                 
In this Age, most folks use cellphones. They entrust all the most
intimate details of their own lives and the lives of their family,
friends, and cow-orkers to their cellphones. Yes, they do! They put a
lot of sensitive information into a portable device that may be lost,
damaged, or stolen. And --- further --- all that information is
ingested and monetized by the curator of the ecosystem that manages
the software that runs the cellphone.
                                 
It\'s very insecure. I deal with customers facing the loss of their
cellphone information nearly every week at work. You can look at the
customer as having lost control of his information. It\'s sad. I\'m
not saying everyone should get rid of his cellphone. I\'m just saying
he shouldn\'t entrust his cellphone with more than the minimum amount
of information. To use a cellphone, you have to put in contacts, of
course, but there is no need to go overboard and put in more than a
handful, for instance. Likewise, your calendar should be for
work-related appointments and not much else.
                                 
What happens to people is that they use different apps. They use
different apps from time to time.  They use different apps than their
family, friends, and cow-orkers use. They use different apps for
different things. Hardly any of these apps allow exporting the users\'
information. Hardly any of the apps can fully read the information
exported by other apps. Information interchange is a fantasy.
                                 
People don\'t manage their relationships with their cloud-based
service providers well, either. However good their intentions, people
just can\'t seem to remember their cloud passwords, and they\'re
pretty much at sea when it comes to establishing and maintaining a
cloud identity, so regaining access to private information may not be
possible after losing or damaging a cellphone.
                                 
I, myself, use a bevy of apps to do the same things on my cellphone
that I do with Tonto2 on my desktop. I use a calendar app, an alarm
app, and a memo app. (Come to think of it, my memo app, Memento
Database (MementoDB) is functionally a lot like Tonto2, although
Memento Database on cellphones is profoundly more sophisticated than
Tonto2 on desktops.) I use a couple of browsers --- one more secure
and one less so --- just as I do on my desktop. I mention the separate
browsers because they keep separate lists of bookmarked links. The
phone itself keeps my contact list, but I keep two phones. You can see
that if I were to put too much information into these apps, I\'d have
a difficult time of moving it around between apps, so I just don\'t. I
wish I could say that Tonto2 could help. It can\'t, and I apologize
for that.
                                 
What Tonto2 aspires to do is to provide consistent repositories for
different kinds of lists.  These reside on your PC, which, if it is a
desktop machine, is bound to be more secure than a cellphone. You
should, of course, take steps to make sure it is more secure: powering
it from a surge protector or an uninterruptible power supply, creating
backups on schedule, not running any server-side software if you can
help it, and restricting physical access to it. By acting as a central
repository for your lists, Tonto2 helps you avoid the pitfalls of
moving information from machine to machine and between apps.
                                 
By using Tonto2 to store your information in **csv** format, which is
simple and well understood, you can abandon Tonto2 whenever you like
and move your information into other paradigms such as databases or
spreadsheets.
                                 
If you are like most people who use a desktop computer, Tonto2 is for
you.
                                 
It may be worth a try.           

See complete docs at <https://LacusVeris.com/Tonto2/Docs/en>.
